@@ -18,14 +18,14 @@ test_that("outputs like r2dii.analysis::target_sda()", {
 
   # Pick small data for speed. "package::f()" is to emphasize integration
   loanbook <- r2dii.data::loanbook_demo
-  ald <- filter(r2dii.data::ald_demo, !is.na(.data$emission_factor))
+  abcd <- filter(r2dii.data::abcd_demo, !is.na(.data$emission_factor))
   scenario <- r2dii.data::co2_intensity_scenario_demo
   region_isos <- r2dii.data::region_isos_demo
 
-  expected <- r2dii.match::match_name(loanbook, ald) %>%
+  expected <- r2dii.match::match_name(loanbook, abcd) %>%
     r2dii.match::prioritize() %>%
     r2dii.analysis::target_sda(
-      ald,
+      abcd,
       co2_intensity_scenario = scenario,
       region_isos = region_isos
     ) %>%
